@@ -11,10 +11,10 @@
 import os
 from unittest.mock import patch
 
-import packaging
+import packvers
 import pytest
 from commoncode.testcase import FileDrivenTesting
-from packaging.requirements import Requirement
+from packvers.requirements import Requirement
 
 from _packagedcode import models
 from python_inspector.api import get_resolved_dependencies
@@ -120,12 +120,12 @@ def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
     assert plist == [
         "pkg:pypi/click@8.1.3",
         "pkg:pypi/flask@2.1.3",
-        "pkg:pypi/importlib-metadata@5.0.0",
+        "pkg:pypi/importlib-metadata@6.0.0",
         "pkg:pypi/itsdangerous@2.1.2",
         "pkg:pypi/jinja2@3.1.2",
         "pkg:pypi/markupsafe@2.1.1",
         "pkg:pypi/werkzeug@2.2.2",
-        "pkg:pypi/zipp@3.10.0",
+        "pkg:pypi/zipp@3.11.0",
     ]
 
 
@@ -146,17 +146,17 @@ def test_without_supported_wheels():
     assert plist == [
         "pkg:pypi/autobahn@22.3.2",
         "pkg:pypi/cffi@1.15.1",
-        "pkg:pypi/cryptography@38.0.3",
+        "pkg:pypi/cryptography@39.0.0",
         "pkg:pypi/hyperlink@21.0.0",
         "pkg:pypi/idna@3.4",
         "pkg:pypi/pycparser@2.21",
-        "pkg:pypi/setuptools@65.5.1",
-        "pkg:pypi/txaio@22.2.1",
+        "pkg:pypi/setuptools@66.0.0",
+        "pkg:pypi/txaio@23.1.1",
     ]
 
 
 def test_is_valid_version():
-    parsed_version = packaging.version.parse("2.1.2")
+    parsed_version = packvers.version.parse("2.1.2")
     requirements = {"flask": [Requirement("flask>2.0.0")]}
     bad_versions = []
     identifier = "flask"
@@ -164,7 +164,7 @@ def test_is_valid_version():
 
 
 def test_is_valid_version_with_no_specifier():
-    parsed_version = packaging.version.parse("2.1.2")
+    parsed_version = packvers.version.parse("2.1.2")
     requirements = {"flask": [Requirement("flask")]}
     bad_versions = []
     identifier = "flask"
@@ -172,7 +172,7 @@ def test_is_valid_version_with_no_specifier():
 
 
 def test_is_valid_version_with_no_specifier_and_pre_release():
-    parsed_version = packaging.version.parse("1.0.0b4")
+    parsed_version = packvers.version.parse("1.0.0b4")
     requirements = {"flask": [Requirement("flask")]}
     bad_versions = []
     identifier = "flask"
